pro rd1soonfits, file, extention, head, data, nodata=nodata, $
  error_id=error_id, help=help
;+
;
; PROJECT:
;       Master's Thesis
; NAME:
;       rd1soonfits
; PURPOSE:
;       Read a single header and optionally the associated image
;	from a SOONSPOT extended FITS file.
; CALLING SEQUENCE:
;       rd1soonfits, file, extention, hdr [, data, nodata=nodata, [help=help]
; INPUTS:
;       file - Name of SOONSPOT extended FITS file.
; OPTIONAL INPUTS: 
;       extention - image number to extract within the file.
; OUTPUTS:
;	FITS header of requested image
; OPTIONAL OUTPUTS:
;       512x512 byte array containing the SOONSPOT image.
; KEYWORD PARAMETERS: 
;       help - Call doc_library and list header, and return
; CALLS:
;       None.
; COMMON BLOCKS:
;       None.
; RESTRICTIONS: 
;       None.
; SIDE EFFECTS:
;       None.
; CATEGORY:
;       Randy Meisner's Master's Thesis.
; PREVIOUS HISTORY:
;       Written March 23, 1997, by Randy Meisner, HAO/NCAR, Boulder, CO
; MODIFICATION HISTORY:
; VERSION:
;       Version 1, March 23, 1997
;-

error_id = 0l
on_ioerror, io_error

if(n_elements(help) gt 0) then begin
  doc_library,'soonfits'
  goto, exit
endif

if(n_params() lt 3 or n_params() gt 4) then begin
  print, ''
  print, 'Usage: 
  print, '  rd1soonfits, file, extention, hdr [, data, nodata=nodata, [help=help]'
  print, ''
  goto, exit
endif

if n_elements(extention) eq 0 then extension = 0

; Open the file and obtain the total number of available images:
openr, lun0, file, /get_lun
check = fstat(lun0)
fstep = long(270720)		; File pointer constant
maxim = check.size/float(fstep)

if keyword_set(verbose) then begin
  print, '% SOONFITS:  ' + strtrim(string(maxim), 2) + ' images available ' + $
	 'in ' + file + '.'
  print, ''
endif

; Define header and image variables:
hdr = bytarr(80, 72)
data = bytarr(512, 512)

if extention gt maxim then begin
  print, ''
  print, '% SOONFITS:  Extention number exceeds number of images in file'
  print, '% SOONFITS:  Returning...'
  free_lun, lun0
  goto, exit
endif
   
; Position the file pointer to the requested image within the file:
pointlun = fstep*extention
point_lun, lun0, pointlun

if keyword_set(verbose) then begin
  print, '% SOONFITS:  Reading image ' + strtrim(string(extention), 2) + $
	 '...'
  print, ''
endif

; Get header and, optionally, image:
readu, lun0, hdr
head = string(hdr > 32b)	; Convert the header to string array
if keyword_set(nodata) eq 0 then readu, lun0, data

free_lun, lun0
goto, exit

io_error:
  error_id=!err
  print, ' Read error encountered.  Returning.'

exit:

end
