pro rdsoonfits, file, extension, hdr, data, $
  error_id=error_id, help=help
;+
; NAME:
;       rdsoonfits
; PURPOSE:
;       Read selected images and/or headers header from a SOONSPOT
;	extended FITS file.
; CALLING SEQUENCE:
;       rdsoonfits, file, extension, hdr [, data, nodata=nodata, [help=help]
; INPUTS:
;       file - Name of SOONSPOT extended FITS file.
; OPTIONAL INPUTS: 
;       extension - vector of image numbers to extract from file.
; OUTPUTS:
;	hdr - structure of FITS header of requested images
;	data - array of images
; KEYWORD PARAMETERS: 
;       help - Call doc_library and list header, and return
; CALLS:
;       None.
; COMMON BLOCKS:
;       None.
; RESTRICTIONS: 
;       None.
; SIDE EFFECTS:
;       None.
; HISTORY:
;       Based on Randy Meisner's soonfits.pro
; MODIFICATION HISTORY:
; VERSION:
;       Version 1, August 24, 1998
;-

error_id = 0l
on_ioerror, io_error

if(n_elements(help) gt 0) then begin
  doc_library,'rdsoonfits'
  goto, exit
endif

if(n_params() lt 3 or n_params() gt 4) then begin
  print, ''
  print, ' Usage: 
  print, '   rdsoonfits, file, extension, hdr [, data, [help=help]'
  print, ''
  goto, exit
endif

; Open the file and obtain the total number of available images:
openr, lun0, file, /get_lun
check = fstat(lun0)
fstep = long(270720)		; File pointer constant
nimg = check.size/float(fstep)

if extension gt nimg then begin
  print, ''
  print, '% SOONFITS:  A requested extension number exceeds number of images in file'
  print, '% SOONFITS:  Returning...'
  print, ''
  free_lun, lun0
  goto, exit
endif

if extension eq -1 then ss = indgen(nimg) else ss = extension

if keyword_set(verbose) then begin
  print, '% SOONFITS:  ' + strtrim(string(nimg), 2) + ' images available ' + $
	 'in ' + file + '.'
  print, ''
endif

; Define header and image variables:
head = bytarr(80, 72)
data0 = bytarr(512, 512)
data_arr = bytarr(512, 512, n_elements(ss))

for i=0, n_elements(ss) do begin

; Position the file pointer to the requested image within the file:
  pointlun = fstep*ss(i)
  point_lun, lun0, pointlun

  if keyword_set(verbose) then begin
    print, '% SOONFITS:  Reading image ' + strtrim(string(extension), 2) + $
	   '...'
    print, ''
  endif

; Get header and, optionally, image:
STOP
  readu, lun0, head
  head = string(head > 32b)	; Convert the header to string array
  if i eq 0 then $
    hdr = fitshead2struct(head, /add_standard) else $
    hdr = concat_struct(hdr, fitshead2struct(head, /add_standard))
  if n_elements(data) gt 0 then begin
STOP
    readu, lun0, data0
    data_arr(0,0,i) = data0
  endif

endfor

free_lun, lun0
goto, exit

io_error:
  error_id=!err
  print, ' Read error encountered.  Returning.'

exit:

end
